@@ -112,7 +112,7 @@ class Command(BaseCommand):
                     app_list[app_config] = None
 
         if related:
-            if len(app_list) != 1 or len(app_list.values()[0]) != 1:
+            if len(app_list) != 1 or len(list(app_list.values())[0]) != 1:
                 raise CommandError("you can only use --related option with one model")
 
         # Check that the serialization format exists; this is a shortcut to
